.. loganom documentation master file, created by
   sphinx-quickstart on Sun May 24 17:42:26 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

loganom
=======

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   usage
   config
   changelog
   ideas

* :ref:`search`